Index: chrome/browser/resources/ntp4/most_visited_page.js |
=================================================================== |
--- chrome/browser/resources/ntp4/most_visited_page.js (revision 98872) |
+++ chrome/browser/resources/ntp4/most_visited_page.js (working copy) |
@@ -91,7 +91,7 @@ |
var faviconDiv = this.querySelector('.favicon'); |
var faviconUrl = data.faviconUrl || |
- 'chrome://favicon/size/32/' + data.url; |
+ 'chrome://favicon/size/16/' + data.url; |
faviconDiv.style.backgroundImage = url(faviconUrl); |
faviconDiv.dir = data.direction; |
if (data.faviconDominantColor) { |
@@ -259,8 +259,8 @@ |
* @return {number} The height. |
*/ |
function heightForWidth(width) { |
- // The 2s are for borders, the 23 is for the title. |
- return (width - 2) * 132 / 212 + 2 + 23; |
+ // The 2s are for borders, the 31 is for the title. |
+ return (width - 2) * 132 / 212 + 2 + 31; |
} |
var THUMBNAIL_COUNT = 8; |